FlutterChainLibrary class

Constructors

FlutterChainLibrary(FlutterChainService blockchainService, Repository<Wallet> walletRepository)
FlutterChainLibrary.defaultInstance()
factory

Properties

blockchainService → FlutterChainService
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
walletRepository → Repository<Wallet>
final
walletsStream → BehaviorSubject<List<Wallet>>
final

Methods

addBlockChainDataByDerivationPath({required DerivationPath derivationPath, required String blockchainType, required String walletID}) → Future<BlockChainData>
callSmartContractFunction({required TransferRequest transferRequest}) → Future<BlockchainResponse>
createWalletByImportedMnemonic({required String mnemonic, required String walletName, String passphrase = ''}) → Future<Wallet>
createWalletWithGeneratedMnemonic({required String walletName, String passphrase = ''}) → Future<Wallet>
deleteAllWallets() → Future<bool>
deleteWalletById({required String walletId}) → Future<bool>
getBalanceOfAddressOnSpecificBlockchain({required TransferRequest transferRequest}) → Future<String>
getBlockchainsUrlsByBlockchainType(String blockchainType) → Set<String>
initCryptoLib() → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendTransferNativeCoin({required TransferRequest transferRequest}) → Future<BlockchainResponse>
setBlockchainNetworkEnvironment({required String blockchainType, required String newUrl}) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited