NearTransferRequest class

Implemented types

Constructors

NearTransferRequest({BlockChainSmartContractArguments? arguments, DerivationPath? derivationPath, DerivationPath? currentDerivationPath, String? fromAddress, String? mnemonic, String? newUrl, String? passphrase, String? privateKey, String? publicKey, String? toAddress, String? transferAmount, String? walletId, String? walletName, String? accountID, String? gas})

Properties

accountID ↔ String?
getter/setter pairoverride
arguments ↔ BlockChainSmartContractArguments?
getter/setter pairoverride
blockchainType ↔ String
getter/setter pairoverride
currentDerivationPath ↔ DerivationPath?
getter/setter pairoverride
derivationPath ↔ DerivationPath?
getter/setter pairoverride
fromAddress ↔ String?
getter/setter pairoverride
gas ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mnemonic ↔ String?
getter/setter pairoverride
newUrl ↔ String?
getter/setter pairoverride
passphrase ↔ String?
getter/setter pairoverride
privateKey ↔ String?
getter/setter pairoverride
publicKey ↔ String?
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toAddress ↔ String?
getter/setter pairoverride
transferAmount ↔ String?
getter/setter pairoverride
walletId ↔ String?
getter/setter pairoverride
walletName ↔ String?
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited