BitcoinRpcClient class

Constructors

BitcoinRpcClient({required BitcoinNetworkClient networkClient})
BitcoinRpcClient.defaultInstance()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
networkClient → BitcoinNetworkClient
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAccountBalance(String adressId) → Future<String>
getAccountBalanceWithAdress(String adress, [bool testNetwork = true]) → Future<String>
getActualPricesFeeSAll() → Future<BlockchainResponse>
getActualPricesFeeSHigher() → Future<int>
getExecutedTxData({required String txHash, bool testNetwork = true}) → Future<Map<String, dynamic>>
getFeeRate({bool testNetwork = true}) → Future<double>
getTransactionInfo(String accountID, String transferAmount, int actuelFees) → Future<BitcoinTransactionInfoModel>
getUTXOs({required String address, bool testNetwork = true}) → Future<List<Map<String, dynamic>>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendTransaction(String txhex) → Future<BlockchainResponse>
sendTransferNativeCoinTest(String txhex) → Future<BlockchainResponse>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited