NearNetworkClient class

Inheritance

Constructors

NearNetworkClient({required String baseUrl, required Dio dio})

Properties

dio → Dio
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteHTTP(String url, dynamic data) → Future<ApiResponse>
inherited
getRequest(String url) → Future<ApiResponse>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postHTTP(String url, dynamic data) → Future<ApiResponse>
inherited
putHTTP(String url, dynamic data) → Future<ApiResponse>
inherited
setUrl(String newUrl) → void
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited