BNBBlockChainService class

Implemented types

Constructors

BNBBlockChainService({required JsVMService jsVMService, required EVMRpcClient bnbRpcClient})
BNBBlockChainService.defaultInstance()
factory

Properties

bnbRpcClient → EVMRpcClient
final
hashCode → int
The hash code for this object.
no setterinherited
jsVMService → JsVMService
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

callSmartContractFunction(TransferRequest transferRequest) → Future<BlockchainResponse>
override
createPayloadForNearMPC({required String receiverAddress, required double amount, required EVMTransactionInfo transactionInfo, String? smartContractCallEncoded, String typeOfNetwork = "testnet"}) → Future<MpcTransactionInfo>
Create payload for Near MPC using Ethereum data
encodeSmartContractCall({required String functionSignature, List parameters = const []}) → Future<String>
Encode the smart contract call using the ABI (Application Binary Interface)
getBlockChainDataByDerivationPath({required String mnemonic, required String? passphrase, required DerivationPath derivationPath}) → Future<BlockChainData>
override
getBlockChainDataFromMnemonic(String mnemonic, String passphrase) → Future<BlockChainData>
override
getBlockchainNetworkEnvironment() → Future<String>
override
getBlockchainsUrlsByBlockchainType() → Set<String>
override
getTransactionInfo({required String from, String? to, String? data, double? amountInEth}) → Future<EVMTransactionInfo>
getWalletBalance(TransferRequest transferRequest) → Future<String>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendTransaction(String txhex) → Future<BlockchainResponse>
sendTransferNativeCoin(TransferRequest transferRequest) → Future<BlockchainResponse>
override
setBlockchainNetworkEnvironment({required String newUrl}) → Future<void>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited