XRPBlockChainService class

Implemented types

Constructors

XRPBlockChainService({required JsVMService jsVMService, required XRPRpcClient xrpRpcClient})
XRPBlockChainService.defaultInstance()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
jsVMService → JsVMService
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
xrpRpcClient → XRPRpcClient
final

Methods

callSmartContractFunction(TransferRequest transferRequest) → Future<BlockchainResponse>
override
createPayloadForNearMPC({required MPCAccountInfo mpcAccountInfo, required String receiverAddress, required double amount, required XRPTransactionInfo transactionInfo, String typeOfNetwork = "testnet"}) → Future<MpcTransactionInfo>
getBlockChainDataByDerivationPath({required String mnemonic, required String? passphrase, required DerivationPath derivationPath}) → Future<BlockChainData>
override
getBlockChainDataFromMnemonic(String mnemonic, String passphrase) → Future<BlockChainData>
override
getBlockchainNetworkEnvironment() → Future<String>
override
getBlockchainsUrlsByBlockchainType() → Set<String>
override
getTransactionInfo({required String senderAdress}) → Future<XRPTransactionInfo>
getWalletBalance(TransferRequest transferRequest) → Future<String>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendTransaction(String txhex) → Future<BlockchainResponse>
sendTransferNativeCoin(TransferRequest transferRequest) → Future<BlockchainResponse>
override
setBlockchainNetworkEnvironment({required String newUrl}) → Future<void>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited