FlutterChainService class

Constructors

FlutterChainService({required JsVMService jsVMService, required NearBlockChainService nearBlockchainService, required BitcoinBlockChainService bitcoinBlockchainService})
FlutterChainService.defaultInstance()
factory

Properties

blockchainServices → Map<String, BlockChainService>
final
hashCode → int
The hash code for this object.
no setterinherited
jsVMService → JsVMService
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

callSmartContractFunction({required TransferRequest transferRequest}) → Future<BlockchainResponse>
createBlockchainsDataFromTheMnemonic({required String mnemonic, required String passphrase}) → Future<Map<String, Set<BlockChainData>>>
generateNewWallet({String passphrase = '', required String walletName}) → Future<Wallet>
getBlockchainNetworkEnvironment({required String blockchainType}) → Future<String>
getBlockchainsUrlsByBlockchainType(String blockchainType) → Set<String>
getWalletBalance({required TransferRequest transferRequest}) → Future<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendTransferNativeCoin({required TransferRequest transferRequest}) → Future<BlockchainResponse>
setBlockchainNetworkEnvironment({required String blockchainType, required String newUrl}) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited